This is a wrapper crate for cookies, that implements the std::convert::From for several
other cookie types/crates, like cookie,
cookie_store and the thirtyfour cookie
type.
It also supports creating cookies from a string in the cookies.txt/netscape format.
let mut cookies_file = File::open("foo.txt")?;
let mut cookie_txt = String::new();
cookies_file.read_to_string(&mut cookie_txt)?;
let cookies = Cookies::try_from(&cookie_txt)?;Structs
Enums
- Parse
Error - represents an error that can occur while parsing or converting cookies